from genericpath import exists
import unittest
import pytest
from pathlib import Path

from PIL import Image
from pillow_heif import register_heif_opener

from heic2png.heic2png import HEIC2PNG

class TestHEIC2PNG(unittest.TestCase):

    __test_input_filename = './test.heic'
    __test_output_filename = './test.png'

    def test_save(self):

        img = Image.new('RGB', (30, 30), color = 'red')
        img.save(self.__test_input_filename)
        heic2png_obj = HEIC2PNG(self.__test_input_filename)
        heic2png_obj.save(output_image_file_path=self.__test_output_filename)
        self.assertTrue(Path(self.__test_output_filename).exists())

    @pytest.fixture(autouse=True)
    def run_around_tests(self):
        # before
        register_heif_opener()
        yield
        # after
        input_file = Path(self.__test_input_filename)
        output_file = Path(self.__test_output_filename)
        if input_file.exists():
            input_file.unlink()
        if output_file.exists():
            output_file.unlink()


if __name__ == '__main__':
    unittest.main()



from fire import Fire
from pillow_heif import register_heif_opener

from .heic2png import HEIC2PNG

def cli(input_path:str, output_path:str=None):
    print(f'----- Input file path is `{input_path}`')
    if output_path:
        print(f'----- Set the output path is `{output_path}`')
    try:
        heic_img = HEIC2PNG(input_path)
        print(f'----- Processing...')
        output_path = heic_img.save(output_path)
        print(f'----- Output file path is `{output_path}`')
    except FileExistsError:
        print('----- File has been already existed!')
    except ValueError:
        print('----- You need to check the format of image!')
        print('Input must be `.heic` and output must be `.png`.')
    except Exception as e:
        print(f'----- Error with {e}')
        print('----- Please report this issue!')

def main():
    register_heif_opener()
    Fire(cli)



from pathlib import Path

from PIL import Image

from pillow_heif import register_heif_opener
register_heif_opener()

class HEIC2PNG:
    def __init__(self, image_file_path:str):
        self.image_file_path = Path(image_file_path)
        if self.image_file_path.suffix.lower() != '.heic':
            raise ValueError
        
        self.image = Image.open(self.image_file_path)

    def save(self, output_image_file_path=None, extension='.png') -> Path:
        if output_image_file_path:
            output_path = Path(output_image_file_path)
            if output_path.suffix.lower() != extension:
                raise ValueError
        else:
            output_path = self.image_file_path.with_name(f"{self.image_file_path.stem}{extension}")
        if output_path.exists():
            raise FileExistsError
        self.image.save(output_path)
        return output_path
